@@ -2,15 +2,13 @@
 #' @export
 fill_labels <- function(x, ...) {
   # evaluate arguments, generate data
-  .dat <- get_dot_data(x, dplyr::quos(...))
+  .dat <- get_dot_data(x, rlang::quos(...))
 
   if (is.data.frame(x)) {
     # iterate variables of data frame
     for (i in colnames(.dat)) {
       x[[i]] <- fill_labels_helper(.dat[[i]])
     }
-    # coerce to tibble
-    x <- tibble::as_tibble(x)
   } else {
     x <- fill_labels_helper(.dat)
   }
